summaryrefslogtreecommitdiff
path: root/src/include/storage/large_object.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/storage/large_object.h')
-rw-r--r--src/include/storage/large_object.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/include/storage/large_object.h b/src/include/storage/large_object.h
index 609bb80459..b662b3b14c 100644
--- a/src/include/storage/large_object.h
+++ b/src/include/storage/large_object.h
@@ -8,7 +8,7 @@
* Portions Copyright (c) 1996-2004, PostgreSQL Global Development Group
* Portions Copyright (c) 1994, Regents of the University of California
*
- * $PostgreSQL: pgsql/src/include/storage/large_object.h,v 1.29 2004/08/29 04:13:10 momjian Exp $
+ * $PostgreSQL: pgsql/src/include/storage/large_object.h,v 1.30 2004/09/16 16:58:42 tgl Exp $
*
*-------------------------------------------------------------------------
*/
@@ -20,7 +20,7 @@
* Data about a currently-open large object.
*
* id is the logical OID of the large object
* xid is the transaction Id that opened the LO (or currently owns it)
* offset is the current seek offset within the LO
* flags contains some flag bits
*
@@ -32,7 +32,7 @@
typedef struct LargeObjectDesc
{
Oid id; /* LO's identifier */
- TransactionId xid; /* owning XID */
+ SubTransactionId subid; /* owning subtransaction ID */
uint32 offset; /* current seek pointer */
int flags; /* locking info, etc */
@@ -20,7 +20,7 @@
*
* id is the logical OID of the large object
- * xid is the transaction Id that opened the LO (or currently owns it)
+ * subid is the subtransaction that opened the LO (or currently owns it)
* offset is the current seek offset within the LO
* flags contains some flag bits